Release history
===============

.. currentmodule:: asyncowfs

.. towncrier release notes start

AsyncOWFS 0.3.0 (2018-09-17)
----------------------------

Features
~~~~~~~~

- AsyncOWFS now auto-generates accessors for reading and writing attributes by
  interrogating ``owserver`` for device attributes. This includes
  subdirectories and arrays.
